Book class

Implementers

Constructors

Book()

Properties

hashCode int
The hash code for this object.
no setterinherited
myTexts Map<String, String>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
texts Map<String, String>
getter/setter pair

Methods

add(String index, String text) bool
molded(String idx, Map<String, String> paramns) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
out(String index) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited